# upstream_tracking.inc - This file contains data that tracks the
# upstream project associated with a given recipe. This list is needed
# for recipes that version information can not be automagically discovered.
# As we automate this checking, this file will slowed be reduced.
#
# This data is used by the package reporting system (packages.yoctoproject.org)
#
# The format is as a bitbake variable override for each recipe
#
#       RECIPE_UPSTREAM_VERSION_pn-<recipe name> = "<version>"
#       RECIPE_UPSTREAM_DATE_pn-<recipe name> = "Mmm dd, YYYY"
#	 - This is the latest upstream version and date
#       RECIPE_NO_UPDATE_REASON_pn-<recipe name> = "<free form text>"
#        - Used to note why a recipe should not be upgraded to a newer versoin
#       CHECK_DATE_pn-<recipe name> = "Mmm dd, YYYY"
#        - This is the date that upstream was last manually checked over time
#          this should be removed as we automate this checking
#
# These entries will slowly be removed as we can automatically determine
# the information in this file.  So for existing recipes that we can get 
# from the package reporting system, the entries here can be removed.
#
# Please keep this list in alphabetical order.
#
RECIPE_UPSTREAM_VERSION_pn-acpid = "1.0.10"
RECIPE_UPSTREAM_DATE_pn-acpid = "Apr 22, 2009"
CHECK_DATE_pn-acpid = "Jul 06, 2012"
RECIPE_UPSTREAM_VERSION_pn-adt-installer = "1.1"
RECIPE_UPSTREAM_DATE_pn-alsa-utils="Jan 25, 2012"
RECIPE_UPSTREAM_VERSION_pn-apmd = "3.2.2-14"
RECIPE_UPSTREAM_DATE_pn-apmd = "Jul 01, 2009"
CHECK_DATE_pn-apmd = "Jul 12, 2011"
RECIPE_UPSTREAM_VERSION_pn-apr-util = "1.3.12"
RECIPE_UPSTREAM_VERSION_pn-apr = "1.4.5"
RECIPE_UPSTREAM_VERSION_pn-apt = "0.8.15.9"
CHECK_DATE_pn-apt = "Jan 18, 2012"
RECIPE_UPSTREAM_DATE_pn-apt = "Oct 14, 2011"
RECIPE_UPSTREAM_VERSION_pn-aspell = "0.60.6"
RECIPE_UPSTREAM_VERSION_pn-at = "3.1.13"
RECIPE_UPSTREAM_VERSION_pn-atk = "1.32.0"
RECIPE_UPSTREAM_DATE_pn-atk = "Sep 01, 2010"
CHECK_DATE_pn-at = "Mar 15, 2012"
RECIPE_UPSTREAM_DATE_pn-at = "unknown"
RECIPE_UPSTREAM_VERSION_pn-autoconf="2.68"
RECIPE_NO_UPDATE_REASON_pn-autoconf="seeing rpm issue with the 2.68 version, a bug is open"
RECIPE_UPSTREAM_VERSION_pn-autogen = "5.12"
CHECK_DATE_pn-autogen = "Jan 17, 2012"
RECIPE_NO_UPDATE_REASON_pn-autogen = "newer versions are dumping core while building, and no distro has picked up the newer versions yet"
RECIPE_UPSTREAM_VERSION_pn-automake="1.11.3"
CHECK_DATE_pn-automake = "Mar 14, 2012"
RECIPE_UPSTREAM_DATE_pn-avahi-ui = "Oct 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-avahi = "0.6.31"
RECIPE_UPSTREAM_DATE_pn-avahi = "Oct 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-bash = "4.1"
RECIPE_UPSTREAM_DATE_pn-bash = "Dec 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-bc = "1.06"
RECIPE_UPSTREAM_DATE_pn-bc = "Nov 01, 2000"
RECIPE_UPSTREAM_VERSION_pn-bdwgc = "20110107"
RECIPE_NO_UPDATE_REASON_pn-bdwgc = "20110107 is same as the 7.2alpha5"
CHECK_DATE_pn-bdwgc = "Feb 01, 2012"
RECIPE_UPSTREAM_VERSION_pn-beecrypt = "4.2.1"
RECIPE_UPSTREAM_DATE_pn-beecrypt = "Jul 12, 2009"
CHECK_DATE_pn-beecrypt = "Jul 06, 2012"
RECIPE_UPSTREAM_VERSION_pn-bigreqsproto="1.1.0"
RECIPE_UPSTREAM_DATE_pn-bigreqsproto="Aug 26, 2009"
RECIPE_UPSTREAM_VERSION_pn-bind = "9.7.2-P3"
RECIPE_NO_UPDATE_REASON_pn-bind = "Latest Stable version, newer versions are Alpha/Beta"
RECIPE_UPSTREAM_VERSION_pn-binutils="2.22"
CHECK_DATE_pn-binutils = "Nov 23, 2011"
RECIPE_UPSTREAM_VERSION_pn-bison="2.4.3"
RECIPE_UPSTREAM_VERSION_pn-blktool = "4-6"
RECIPE_UPSTREAM_DATE_pn-blktool = "Feb 01, 2010"
CHECK_DATE_pn-blktool = "Jul 12, 2011"
RECIPE_UPSTREAM_VERSION_pn-blktrace = "1.0.1"
RECIPE_UPSTREAM_VERSION_pn-blktrace = "a788dfde86dfaff8f1c277a233f92c1822e06b76"
RECIPE_UPSTREAM_DATE_pn-blktrace = "Dec 01, 2010"
RECIPE_UPSTREAM_DATE_pn-bluez-dtl1-workaround="n/a"
RECIPE_UPSTREAM_VERSION_pn-bluez4="4.98"
RECIPE_UPSTREAM_DATE_pn-bluez4="Jan 13, 2012"
CHECK_DATE_pn-bluez4 = "Jan 22, 2012"
RECIPE_UPSTREAM_DATE_pn-boost-jam-native = "Jun 28, 2012"
RECIPE_UPSTREAM_VERSION_pn-boost = "1.50.0"
CHECK_DATE_pn-boost = "Jul 05, 2012"
RECIPE_UPSTREAM_DATE_pn-boost = "Feb 24, 2012"
RECIPE_UPSTREAM_VERSION_pn-btrfs-tools="git"
RECIPE_UPSTREAM_VERSION_pn-busybox = "1.16.2"
RECIPE_UPSTREAM_DATE_pn-busybox = "Jun 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-byacc="20120115"
CHECK_DATE_pn-byacc = "Feb 01, 2012"
RECIPE_UPSTREAM_VERSION_pn-bzip2 = "1.0.6"
RECIPE_UPSTREAM_DATE_pn-bzip2 = "Mar 01, 2008"
CHECK_DATE_pn-bzip2 = "May 24, 2011"
RECIPE_UPSTREAM_VERSION_pn-cairo="1.9.10"
RECIPE_UPSTREAM_DATE_pn-cairo="Feb 20, 2010"
RECIPE_NO_UPDATE_REASON_pn-cairo="latest version is not stable release"
RECIPE_UPSTREAM_VERSION_pn-calibrateproto = "0.0+git0+1da6fd1e2c7a49648245c98481fabea8b9690a8c"
RECIPE_UPSTREAM_DATE_pn-calibrateproto = "Jan 01, 2008"
RECIPE_UPSTREAM_VERSION_pn-ccache = "3.1.7"
CHECK_DATE_pn-ccache = "Mar 14, 2012"
RECIPE_UPSTREAM_VERSION_pn-cdrtools = "3.00"
RECIPE_UPSTREAM_DATE_pn-cdrtools = "Jun 02, 2010"
RECIPE_NO_UPDATE_REASON_pn-cdrtools = "v3.x uses incompatible CDDL license"
RECIPE_UPSTREAM_VERSION_pn-chkconfig = "1.3.58"
CHECK_DATE_pn-chkconfig = "Mar 14, 2012"
RECIPE_UPSTREAM_VERSION_pn-chrpath = "0.14"
CHECK_DATE_pn-chrpath = "Jul 05, 2012"
RECIPE_UPSTREAM_DATE_pn-chrpath = "Sep 27, 2011"
RECIPE_UPSTREAM_VERSION_pn-claws-plugin-gtkhtml2-viewer = "0.27"
RECIPE_UPSTREAM_VERSION_pn-clipboard-manager = "0.6.8"
RECIPE_UPSTREAM_VERSION_pn-clutter-1.8 = "1.8.4"
RECIPE_UPSTREAM_VERSION_pn-clutter = "1.8.4"
CHECK_DATE_pn-clutter = "Feb 08, 2012"
RECIPE_UPSTREAM_DATE_pn-cmake-native="Nov 03, 2010"
RECIPE_UPSTREAM_VERSION_pn-cogl = "1.8.2"
CHECK_DATE_pn-cogl = "Dec 13, 2011"
RECIPE_UPSTREAM_VERSION_pn-compositeproto = "0.4.2"
RECIPE_UPSTREAM_DATE_pn-compositeproto = "Oct 29, 2010"
RECIPE_UPSTREAM_DATE_pn-connman-gnome="n/a"
RECIPE_UPSTREAM_VERSION_pn-connman = "0.65"
RECIPE_UPSTREAM_DATE_pn-connman="Dec 24, 2010"
RECIPE_UPSTREAM_VERSION_pn-console-tools = "0.3.2"
RECIPE_UPSTREAM_DATE_pn-console-tools = "Feb 18, 2002"
CHECK_DATE_pn-console-tools = "Jul 05, 2012"
RECIPE_UPSTREAM_VERSION_pn-consolekit = "0.4.3"
RECIPE_UPSTREAM_VERSION_pn-core-image-minimal = "1.0"
RECIPE_UPSTREAM_VERSION_pn-coreutils = "8.12"
RECIPE_UPSTREAM_DATE_pn-coreutils = "Apr 01, 2011"
RECIPE_UPSTREAM_VERSION_pn-cpio = "2.11"
RECIPE_UPSTREAM_DATE_pn-cpio = "Mar 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-cracklib="2.8.19"
CHECK_DATE_pn-cracklib = "Jul 05, 2012"
RECIPE_UPSTREAM_DATE_pn-cracklib = "May 18, 2010"
RECIPE_UPSTREAM_VERSION_pn-createrepo = "0.9.9"
RECIPE_NO_UPDATE_REASON_pn-createrepo = "Versions after 0.9.* use YUM, so we hold at 0.4.11"
RECIPE_UPSTREAM_VERSION_pn-cronie = "1.4.8"
CHECK_DATE_pn-cronie = "Aug 16, 2011"
RECIPE_UPSTREAM_DATE_pn-cronie = "Jun 27, 2011"
RECIPE_UPSTREAM_VERSION_pn-cups = "1.5.0"
RECIPE_UPSTREAM_DATE_pn-cups = "Jul 25, 2011"
CHECK_DATE_pn-cups = "Sep 28, 2011"
RECIPE_UPSTREAM_VERSION_pn-curl = "7.23.1"
RECIPE_UPSTREAM_DATE_pn-curl = "Nov 17, 2011"
RECIPE_UPSTREAM_VERSION_pn-cwautomacros = "20110201"
RECIPE_UPSTREAM_DATE_pn-cwautomacros = "Feb 01, 2011"
CHECK_DATE_pn-cwautomacros = "Jul 06, 2012"
RECIPE_UPSTREAM_DATE_pn-cwautomacros = "Feb 01, 2011"
RECIPE_UPSTREAM_VERSION_pn-damageproto = "1.2.1"
RECIPE_UPSTREAM_DATE_pn-damageproto = "Oct 29, 2010"
RECIPE_UPSTREAM_VERSION_pn-db = "5.0.26"
RECIPE_NO_UPDATE_REASON_pn-db= "API compatibility issue"
RECIPE_UPSTREAM_DATE_pn-db = "n/a"
RECIPE_UPSTREAM_DATE_pn-dbus-glib = "Nov 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-dbus = "1.4.16"
RECIPE_UPSTREAM_DATE_pn-dbus = "Sep 21, 2011"
RECIPE_UPSTREAM_VERSION_pn-dhcp = "4.2.3"
RECIPE_UPSTREAM_DATE_pn-dhcp = "Oct 19, 2011"
RECIPE_NO_UPDATE_REASON_pn-dhcp = "We are at latest P2 version"
RECIPE_UPSTREAM_VERSION_pn-diffstat="1.54"
RECIPE_UPSTREAM_VERSION_pn-diffutils = "3.2"
RECIPE_UPSTREAM_DATE_pn-direcfb = "Aug 9, 2011"
RECIPE_UPSTREAM_VERSION_pn-directfb = "1.5.3"
RECIPE_UPSTREAM_VERSION_pn-distcc="2.18.3"
RECIPE_UPSTREAM_VERSION_pn-dmxproto = "2.3.1"
RECIPE_UPSTREAM_DATE_pn-dmxproto = "Jan 5, 2011"
RECIPE_UPSTREAM_DATE_pn-docbook-sgml-dtd = "May 21, 2010"
RECIPE_UPSTREAM_VERSION_pn-dosfstools = "2.11"
RECIPE_UPSTREAM_DATE_pn-dosfstools = "Mar 12, 2005"
CHECK_DATE_pn-dosfstools = "Nov 14, 2011"
RECIPE_UPSTREAM_VERSION_pn-dpkg = "1.16.1.2"
CHECK_DATE_pn-dpkg = "Jan 18, 2012"
RECIPE_UPSTREAM_DATE_pn-dpkg = "Nov 25, 2011"
RECIPE_UPSTREAM_VERSION_pn-dri2proto = "2.6"
RECIPE_UPSTREAM_DATE_pn-dri2proto = "Jun 29, 2011"
RECIPE_UPSTREAM_VERSION_pn-dropbear = "2011.54"
RECIPE_UPSTREAM_DATE_pn-dropbear = "Nov 08, 2011"
RECIPE_UPSTREAM_VERSION_pn-dtc = "37c0b6a0916c31a5eae0a9ddfcc5d0b8fb4569c6"
RECIPE_UPSTREAM_VERSION_pn-e2fsprogs = "1.42.4"
CHECK_DATE_pn-e2fsprogs = "Jul 05, 2012"
RECIPE_UPSTREAM_DATE_pn-e2fsprogs = "Jun 12, 2012"
RECIPE_UPSTREAM_VERSION_pn-ed = "1.6"
RECIPE_UPSTREAM_DATE_pn-ed = "Jan 01, 2012"
RECIPE_UPSTREAM_VERSION_pn-eds-tools = "git"
RECIPE_UPSTREAM_VERSION_pn-eee-acpi-scripts = "1.1.12+9d4cdedca25b396405f8587f9c4fbf8229e041c2"
RECIPE_UPSTREAM_VERSION_pn-eggdbus = "0.6"
RECIPE_UPSTREAM_DATE_pn-eggdbus = "Nov 01, 2009"
CHECK_DATE_pn-eggdbus = "Jul 24, 2012"
RECIPE_UPSTREAM_VERSION_pn-eglibc = "git:16540"
CHECK_DATE_pn-eglibc = "Jan 01, 2012"
RECIPE_UPSTREAM_VERSION_pn-elfutils="0.148"
RECIPE_UPSTREAM_DATE_pn-elfutils="Jun 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-empathy = "2.31.2"
RECIPE_UPSTREAM_VERSION_pn-enchant="1.6.0"
RECIPE_UPSTREAM_DATE_pn-enchant="Apr 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-encodings = "1.0.3"
RECIPE_UPSTREAM_DATE_pn-encodings = "Oct 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-epdfview = "check"
RECIPE_UPSTREAM_VERSION_pn-ethtool = "2.6.36"
CHECK_DATE_pn-ethtool = "Apr 25, 2012"
RECIPE_UPSTREAM_DATE_pn-ethtool = "Nov 17, 2010"
RECIPE_UPSTREAM_VERSION_pn-evieext="1.1.0"
RECIPE_UPSTREAM_DATE_pn-evieext="Aug 26, 2009"
RECIPE_UPSTREAM_DATE_pn-evolution-data-server = "Jun 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-expat = "2.0.1"
CHECK_DATE_pn-expat = "Jul 05, 2012"
RECIPE_UPSTREAM_DATE_pn-expat = "Jun 5, 2007"
RECIPE_UPSTREAM_VERSION_pn-farsight2 = "0.0.20"
RECIPE_UPSTREAM_VERSION_pn-file = "5.11"
RECIPE_UPSTREAM_DATE_pn-file = "Feb 21, 2012"
CHECK_DATE_pn-file = "Feb 27, 2012"
RECIPE_UPSTREAM_VERSION_pn-findutils = "4.4.2"
RECIPE_UPSTREAM_DATE_pn-findutils = "Jun 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-fixesproto = "5.0"
RECIPE_UPSTREAM_DATE_pn-fixesproto = "Mar 8, 2011"
RECIPE_UPSTREAM_VERSION_pn-flac="1.2.1"
RECIPE_UPSTREAM_DATE_pn-flac= "Sep 8, 2007"
CHECK_DATE_pn-flac = "Jul 24, 2012"
RECIPE_UPSTREAM_DATE_pn-flac="Sep 16, 2007"
RECIPE_UPSTREAM_VERSION_pn-flex = "2.5.35"
RECIPE_UPSTREAM_DATE_pn-flex = "Feb 02, 2008"
CHECK_DATE_pn-flex = "Jul 06, 2012"
RECIPE_UPSTREAM_DATE_pn-font-alias = "Oct 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-fontcacheproto = "0.1.3"
RECIPE_UPSTREAM_DATE_pn-fontcacheproto = "Oct 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-fontconfig = "2.9.0"
RECIPE_UPSTREAM_DATE_pn-fontconfig = "Mar 10, 2012"
RECIPE_UPSTREAM_VERSION_pn-fontsproto = "2.1.2"
RECIPE_UPSTREAM_DATE_pn-fontsproto = "Mar 23, 2012"
RECIPE_UPSTREAM_VERSION_pn-formfactor = "0.0"
RECIPE_UPSTREAM_DATE_pn-formfactor = "n/a"
RECIPE_UPSTREAM_VERSION_pn-fotowall=""
RECIPE_UPSTREAM_VERSION_pn-fotowall="0.9"
RECIPE_UPSTREAM_DATE_pn-fotowall="Dec 08, 2009"
RECIPE_UPSTREAM_VERSION_pn-freetype = "2.4.10"
RECIPE_UPSTREAM_DATE_pn-freetype = "Jun 15, 2012"
CHECK_DATE_pn-freetype = "Jul 06, 2012"
RECIPE_UPSTREAM_VERSION_pn-fstests="0.0+svnr426"
CHECK_DATE_pn-fstests = "Jul 06, 2011"
RECIPE_UPSTREAM_VERSION_pn-fuse = "2.8.4"
RECIPE_UPSTREAM_VERSION_pn-gaku="0.0+svnr399"
RECIPE_UPSTREAM_DATE_pn-gaku="Jul 03, 2008"
RECIPE_UPSTREAM_DATE_pn-galago-daemon = "Oct 7, 2006"
RECIPE_UPSTREAM_VERSION_pn-gamin = "0.1.10"
RECIPE_UPSTREAM_DATE_pn-gamin = "Nov 01, 2008"
RECIPE_UPSTREAM_VERSION_pn-gawk = "4.0.0"
RECIPE_UPSTREAM_VERSION_pn-gcc-runtime = "4.6.2+git"
RECIPE_UPSTREAM_VERSION_pn-gcc="4.7.1+svnr188658"
CHECK_DATE_pn-gcc = "Jul 06, 2012"
RECIPE_UPSTREAM_VERSION_pn-gccmakedep = "1.0.2"
RECIPE_UPSTREAM_DATE_pn-gccmakedep = "May 19, 2006"
RECIPE_UPSTREAM_DATE_pn-gconf-dbus = "n/a"
RECIPE_UPSTREAM_VERSION_pn-gdb="7.4.1"
RECIPE_UPSTREAM_VERSION_pn-gdbm = "1.10"
CHECK_DATE_pn-gdb = "May 01, 2012"
RECIPE_UPSTREAM_DATE_pn-gdbm = "Nov 13, 2011"
RECIPE_UPSTREAM_DATE_pn-gdk-pixbuf-csource-native = "May 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-genext2fs = "1.4.1"
RECIPE_UPSTREAM_DATE_pn-genext2fs = "Apr 01, 2007"
RECIPE_UPSTREAM_VERSION_pn-gettext = "0.18.1.1"
RECIPE_UPSTREAM_DATE_pn-gettext = "Jun 06, 2010"
CHECK_DATE_pn-gettext = "Nov 25, 2011"
RECIPE_UPSTREAM_VERSION_pn-ghostscript = "9.05"
CHECK_DATE_pn-ghostscript = "Mar 14, 2012"
RECIPE_LATEST_VERIONS_pn-git = "1.7.3.4"
RECIPE_UPSTREAM_VERSION_pn-glew = "1.7.0"
CHECK_DATE_pn-glew = "Jul 05, 2012"
RECIPE_UPSTREAM_DATE_pn-glew = "Aug 26, 2011"
RECIPE_UPSTREAM_DATE_pn-glib-2.0 = "Nov 11, 2011"
RECIPE_UPSTREAM_VERSION_pn-glibc = "2.11.2"
RECIPE_UPSTREAM_DATE_pn-glibc = "May 01, 2010"
RECIPE_NO_UPDATE_REASON_pn-glibc = "two glibc plugins are based on 2.10.1"
RECIPE_UPSTREAM_VERSION_pn-glproto = "1.4.15"
RECIPE_UPSTREAM_DATE_pn-glproto = "Jun 29, 2011"
RECIPE_UPSTREAM_VERSION_pn-gmp="5.0.4"
CHECK_DATE_pn-gmp = "Mar 14, 2012"
RECIPE_UPSTREAM_DATE_pn-gnome-vfs = "Sep 28, 2010"
RECIPE_UPSTREAM_VERSION_pn-gnu-config="git"
RECIPE_UPSTREAM_DATE_pn-gnutls = "May 05, 2012"
RECIPE_UPSTREAM_DATE_pn-gobject-introspection = "Mar 05, 2012"
RECIPE_NO_UPDATE_REASON_pn-gobject_introspection = "Does not cross-compile"
RECIPE_UPSTREAM_VERSION_pn-gperf = "3.0.4"
RECIPE_UPSTREAM_DATE_pn-gperf = "Feb 01, 2009"
CHECK_DATE_pn-gperf = "Jul 12, 2011"
RECIPE_UPSTREAM_VERSION_pn-gpgme = "1.3.1"
CHECK_DATE_pn-gpgme = "Jul 28, 2011"
RECIPE_UPSTREAM_DATE_pn-gpgme = "Jun 01, 2011"
RECIPE_UPSTREAM_VERSION_pn-grep = "2.9"
RECIPE_UPSTREAM_DATE_pn-grep = "Jun 01, 2011"
RECIPE_NO_UPDATE_REASON_pn-groff = "1.18.1.4 is latest GPLv2 Version no 1.21"
RECIPE_UPSTREAM_VERSION_pn-groff = "1.21"
RECIPE_UPSTREAM_VERSION_pn-grub = "0.97"
RECIPE_UPSTREAM_DATE_pn-grub = "Dec 01, 2005"
RECIPE_NO_UPDATE_REASON_pn-grub="grub2 is a different thing"
RECIPE_UPSTREAM_VERSION_pn-gssdp = "0.10.0"
RECIPE_UPSTREAM_DATE_pn-gssdp="Apr 07, 2011"
RECIPE_UPSTREAM_DATE_pn-gst-meta-base="n/a"
RECIPE_UPSTREAM_VERSION_pn-gstreamer="0.10.32"
RECIPE_UPSTREAM_DATE_pn-gstreamer="Jan 31, 2011"
RECIPE_NO_UPDATE_REASON_pn-gstreamer="upgrading to 0.11.1 causes gst-fluendo-mpegdemux compilation failure due to API conflicts. Probably 0.11 is not stable enough for some gst-* recipes"
RECIPE_UPSTREAM_VERSION_pn-gthumb = "2.12.4"
RECIPE_UPSTREAM_DATE_pn-gtk-sato-engine = "Feb 01, 2008"
RECIPE_UPSTREAM_VERSION_pn-gtk+ = "2.24.8"
RECIPE_NO_UPDATE_REASON_pn-gtk+ = "Do not upgrade to version: 2.99.2 because prefer stable tree"
RECIPE_UPSTREAM_VERSION_pn-gtkhtml2 = "2.11.1"
RECIPE_UPSTREAM_DATE_pn-gtk+ = "Nov 10, 2011"
RECIPE_UPSTREAM_VERSION_pn-guile = "2.0.3"
CHECK_DATE_pn-guile = "Jan 17, 2012"
RECIPE_UPSTREAM_DATE_pn-gupnp-av= "Apr 08, 2011"
RECIPE_UPSTREAM_VERSION_pn-gupnp = "0.16.1"
RECIPE_UPSTREAM_DATE_pn-gupnp= "Apr 30, 2011"
RECIPE_UPSTREAM_VERSION_pn-gypsy="0.8"
RECIPE_UPSTREAM_DATE_pn-gypsy="Jun 09, 2010"
RECIPE_UPSTREAM_VERSION_pn-gzip = "1.5"
RECIPE_UPSTREAM_DATE_pn-2zip = "Jun 17, 2012"
RECIPE_UPSTREAM_DATE_pn-hal-info = "Nov 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-hal = "0.5.14"
RECIPE_UPSTREAM_DATE_pn-hal = "Nov 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-hdparm = "9.39"
RECIPE_UPSTREAM_DATE_pn-hdparm = "Feb 03, 2012"
CHECK_DATE_pn-hdparm = "Jul 06, 2012"
RECIPE_UPSTREAM_DATE_pn-hicolor-icon-theme = "Sep 01, 2009"
RECIPE_UPSTREAM_DATE_pn-hostap-utils="Dec 03, 2008"
RECIPE_UPSTREAM_VERSION_pn-icu = "3.6"
RECIPE_UPSTREAM_DATE_pn-icu = "Aug 01, 2006"
CHECK_DATE_pn-icu = "Jul 12, 2011"
RECIPE_UPSTREAM_VERSION_pn-imake = "1.0.3"
RECIPE_UPSTREAM_DATE_pn-imake = "Apr 16, 2010"
RECIPE_UPSTREAM_DATE_pn-initramfs-boot = "n/a"
RECIPE_UPSTREAM_VERSION_pn-initscripts = "1.0"
RECIPE_UPSTREAM_DATE_pn-initscripts = "n/a"
RECIPE_UPSTREAM_VERSION_pn-inputproto = "2.1.99.4"
RECIPE_UPSTREAM_DATE_pn-inputproto = "Dec 20, 2011"
RECIPE_NO_UPDATE_REASON_pn-inputproto = "Do not upgrade to version: 2.1.99.4 that has unstable code. 2.2 would be the next stable release."
RECIPE_UPSTREAM_VERSION_pn-insserv = "1.14.0"
CHECK_DATE_pn-insserv = "Jul 12, 2011"
RECIPE_UPSTREAM_DATE_pn-insserv = "unknown"
RECIPE_UPSTREAM_VERSION_pn-intltool="0.40.6"
RECIPE_UPSTREAM_VERSION_pn-iproute2 = "3.3.0"
RECIPE_UPSTREAM_DATE_pn-iproute2 = "Mar 20, 2012"
RECIPE_UPSTREAM_VERSION_pn-iptables = "1.4.13"
RECIPE_UPSTREAM_DATE_pn-iptables = "Apr 28, 2012"
RECIPE_UPSTREAM_VERSION_pn-iputils="s20100418"
RECIPE_UPSTREAM_VERSION_pn-irda-utils = "0.9.18"
RECIPE_UPSTREAM_DATE_pn-irda-utils="Jul 10, 2006"
CHECK_DATE_pn-irda-utils = "Jul 24, 2012"
RECIPE_UPSTREAM_VERSION_pn-iso-codes = "3.16"
RECIPE_UPSTREAM_VERSION_pn-jpeg = "8c"
CHECK_DATE_pn-jpeg = "Dec 24, 2011"
RECIPE_UPSTREAM_DATE_pn-jpeg = "Jan 01, 2011"
RECIPE_UPSTREAM_VERSION_pn-js = "1.7.0+1.8.0rc1"
RECIPE_UPSTREAM_DATE_pn-js = "Mar 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-json-glib = "0.14.2"
RECIPE_UPSTREAM_VERSION_pn-kbproto = "1.0.6"
RECIPE_UPSTREAM_DATE_pn-kbproto = "Mar 23, 2012"
RECIPE_UPSTREAM_VERSION_pn-kern-tools-native = "check"
RECIPE_UPSTREAM_VERSION_pn-kernelshark = "0.2"
RECIPE_NO_UPDATE_REASON_pn-kernelshark = "0.2 is the latest version."
CHECK_DATE_pn-kernelshark = "Mar 16, 2011"
RECIPE_UPSTREAM_DATE_pn-kernelshark = "Nov 7, 2011"
RECIPE_UPSTREAM_DATE_pn-kexec-tools="Jan 15, 2012"
RECIPE_UPSTREAM_VERSION_pn-keymaps = "1.0"
RECIPE_UPSTREAM_DATE_pn-keymaps = "n/a"
RECIPE_UPSTREAM_VERSION_pn-kf = "n/a"
RECIPE_UPSTREAM_VERSION_pn-lame = "3.99.5"
RECIPE_UPSTREAM_DATE_pn-lame = "Feb 28, 2012"
CHECK_DATE_pn-lame = "Jul 06, 2012"
RECIPE_UPSTREAM_VERSION_pn-latencytop = "0.5"
CHECK_DATE_pn-latencytop = "Apr 20, 2011"
RECIPE_UPSTREAM_DATE_pn-latencytop = "Apr 28, 2009"
RECIPE_UPSTREAM_VERSION_pn-leafpad = "0.8.18.1"
RECIPE_UPSTREAM_DATE_pn-leafpad = "Dec 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-less = "444"
CHECK_DATE_pn-less = "Jul 05, 2012"
RECIPE_UPSTREAM_DATE_pn-less = "Jun 9, 2011"
RECIPE_UPSTREAM_VERSION_pn-liba52="0.7.4"
CHECK_DATE_pn-liba52 = "Jan 30, 2011"
RECIPE_UPSTREAM_DATE_pn-liba52="Jul 27, 2002"
RECIPE_UPSTREAM_VERSION_pn-libacpi = "0.2"
RECIPE_UPSTREAM_VERSION_pn-libaio = "0.3.109"
RECIPE_UPSTREAM_DATE_pn-libaio = "Aug 30, 2011"
CHECK_DATE_pn-libaio = "Nov 8, 2011"
RECIPE_UPSTREAM_VERSION_pn-libarchive = "2.8.5"
RECIPE_UPSTREAM_DATE_pn-libarchive = "Sep 3, 2011"
RECIPE_UPSTREAM_DATE_pn-libart-lgpl = "Apr 1, 2010"
RECIPE_UPSTREAM_VERSION_pn-libassuan = "2.0.2"
RECIPE_UPSTREAM_DATE_pn-libassuan = "Jun 01, 2011"
CHECK_DATE_pn-libassuan = "Nov 22, 2011"
RECIPE_UPSTREAM_DATE_pn-libatomics-ops = "unknown"
RECIPE_UPSTREAM_VERSION_pn-libcanberra = "0.26"
RECIPE_UPSTREAM_VERSION_pn-libcap = "2.22"
CHECK_DATE_pn-libcap = "Jul 05, 2012"
RECIPE_UPSTREAM_DATE_pn-libcap = "Jan 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-libcheck = "0.9.8"
CHECK_DATE_pn-libcheck = "Jul 05, 2012"
RECIPE_UPSTREAM_DATE_pn-libcheck = "Sep 23, 2009"
RECIPE_UPSTREAM_VERSION_pn-libconvert-asn1-perl="0.22"
RECIPE_UPSTREAM_VERSION_pn-libcroco = "0.6.3"
RECIPE_UPSTREAM_DATE_pn-libcroco = "Nov 14, 2011"
RECIPE_UPSTREAM_VERSION_pn-libdaemon = "0.14"
RECIPE_UPSTREAM_DATE_pn-libdaemon = "Nov 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-libdmx = "1.1.1"
RECIPE_UPSTREAM_DATE_pn-libdmx = "Oct 28, 2010"
RECIPE_UPSTREAM_DATE_pn-libdrm-poulsbo = "n/a"
RECIPE_UPSTREAM_VERSION_pn-libdrm = "2.4.34"
RECIPE_UPSTREAM_DATE_pn-libdrm = "May 10, 2012"
RECIPE_UPSTREAM_DATE_pn-liberation-fonts = "Feb 09, 2012"
RECIPE_UPSTREAM_VERSION_pn-libetpan = "1.0"
RECIPE_UPSTREAM_VERSION_pn-libevent = "2.0.16"
CHECK_DATE_pn-libevent = "Jan 12, 2012"
RECIPE_UPSTREAM_DATE_pn-libevent = "Nov 18, 2011"
RECIPE_UPSTREAM_DATE_pn-libexif = "Dec 12, 2010"
RECIPE_UPSTREAM_VERSION_pn-libexif = "0.6.20"
CHECK_DATE_pn-libexif = "Jul 05, 2012"
RECIPE_UPSTREAM_VERSION_pn-libfakekey = "0.0+svnr2031"
RECIPE_UPSTREAM_DATE_pn-libfakekey = "Jul 01, 2006"
RECIPE_UPSTREAM_VERSION_pn-libffi  = "3.0.10"
RECIPE_NO_UPDATE_REASON_pn-libffi="3.0.11 is still RC"
RECIPE_UPSTREAM_DATE_pn-libffi = "Aug 23, 2011"
RECIPE_UPSTREAM_VERSION_pn-libfm = "0.1.17"
RECIPE_UPSTREAM_DATE_pn-libfm = "Oct 24, 2011"
CHECK_DATE_pn-libfm = "Jul 06, 2012"
RECIPE_UPSTREAM_VERSION_pn-libfontenc = "1.0.5"
RECIPE_UPSTREAM_DATE_pn-libfontenc = "Aug 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-libfribidi = "0.19.2"
RECIPE_UPSTREAM_VERSION_pn-libgalago = "0.5.2"
RECIPE_UPSTREAM_VERSION_pn-libgcc = "4.6.2+git"
CHECK_DATE_pn-libgcc = "Jan 10, 2012"
RECIPE_UPSTREAM_VERSION_pn-libgcrypt = "1.5.0"
RECIPE_UPSTREAM_DATE_pn-libgcrypt = "Jun 6, 2011"
CHECK_DATE_pn-libgcrypt = "Nov 23, 2011"
RECIPE_UPSTREAM_VERSION_pn-libgdata = "0.8.0"
RECIPE_UPSTREAM_VERSION_pn-libgdbus = "0.2"
CHECK_DATE_pn-libgdbus = "Apr 20, 2012"
RECIPE_UPSTREAM_DATE_pn-libgdbus = "Sep 01, 2008"
RECIPE_UPSTREAM_VERSION_pn-libglade = "2.6.4"
RECIPE_UPSTREAM_DATE_pn-libglade = "Mar 01, 2009"
RECIPE_UPSTREAM_DATE_pn-libgnome-keyring = "Sep 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-libgnomecanvas = "2.30.1"
RECIPE_UPSTREAM_VERSION_pn-libgnomekbd = "2.31.1"
RECIPE_UPSTREAM_DATE_pn-libgpg-error = "Jul 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-libgsf = "1.14.18"
RECIPE_UPSTREAM_VERSION_pn-libgsmd = "5394"
RECIPE_UPSTREAM_DATE_pn-libgsmd ="Aug 06, 2009"
CHECK_DATE_pn-libgsmd = "Jul 06, 2012"
RECIPE_UPSTREAM_VERSION_pn-libgtkstylus = "0.5"
RECIPE_UPSTREAM_VERSION_pn-libical = "0.48"
RECIPE_UPSTREAM_DATE_pn-libical ="Dec 13, 2011"
CHECK_DATE_pn-libical = "Jul 24, 2012"
RECIPE_UPSTREAM_DATE_pn-libical = "Dec 13, 2011"
RECIPE_UPSTREAM_VERSION_pn-libice = "1.0.6"
RECIPE_UPSTREAM_DATE_pn-libice = "Aug 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-libiconv = "1.14"
RECIPE_UPSTREAM_DATE_pn-libiconv = "Aug 07, 2011"
CHECK_DATE_pn-libiconv = "Nov 22, 2011"
RECIPE_UPSTREAM_VERSION_pn-libid3tag="0.15.1b"
RECIPE_UPSTREAM_DATE_pn-libid3tag="Feb 18, 2004"
RECIPE_UPSTREAM_DATE_pn-libidn = "May 23, 2012"
RECIPE_UPSTREAM_VERSION_pn-libjson = "0.9"
RECIPE_UPSTREAM_DATE_pn-libjson = "Jul 31, 2009"
RECIPE_UPSTREAM_VERSION_pn-liblbxutil = "1.1.0"
RECIPE_UPSTREAM_DATE_pn-liblbxutil = "Dec 4, 2009"
RECIPE_UPSTREAM_VERSION_pn-libmad = "0.15.1b"
CHECK_DATE_pn-libmad = "Jul 05, 2012"
RECIPE_UPSTREAM_DATE_pn-libmad = "Feb 18, 2004"
RECIPE_UPSTREAM_VERSION_pn-libmatchbox = "1.9"
RECIPE_UPSTREAM_DATE_pn-libmatchbox = "Aug 01, 2006"
RECIPE_UPSTREAM_VERSION_pn-libmpc="0.8.2"
CHECK_DATE_pn-libmpc = "Jan 25, 2011"
RECIPE_UPSTREAM_VERSION_pn-libmusicbrainz="3.0.3"
RECIPE_UPSTREAM_DATE_pn-libmusicbrainz="Sep 27, 2010"
RECIPE_UPSTREAM_VERSION_pn-libnewt = "0.52.14"
CHECK_DATE_pn-libnewt = "Mar 14, 2012"
RECIPE_UPSTREAM_VERSION_pn-libnfsidmap = "0.24"
RECIPE_UPSTREAM_DATE_pn-libnfsidmap = "Dec 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-libnice = "0.0.12"
RECIPE_UPSTREAM_VERSION_pn-libnl = "2.0"
RECIPE_NO_UPDATE_REASON_pn-libnl = "libnl-3.2.2 is incompatible with libnl2, so no Upgrade"
RECIPE_UPSTREAM_DATE_pn-libnl = "Oct 01, 2010"
RECIPE_UPSTREAM_DATE_pn-libnss-mdns = "May 01, 2007"
RECIPE_UPSTREAM_VERSION_pn-libogg="1.3.0"
RECIPE_UPSTREAM_DATE_pn-libogg="Aug 04, 2011"
RECIPE_UPSTREAM_VERSION_pn-liboil = "0.3.17"
RECIPE_UPSTREAM_DATE_pn-liboil = "Feb 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-libomxil = "0.9.3"
RECIPE_UPSTREAM_DATE_pn-libomxil = "May 20, 2011"
CHECK_DATE_pn-libomxil = "Jul 24, 2012"
RECIPE_UPSTREAM_VERSION_pn-libopensync-plugin-evolution2 = "0.39"
RECIPE_UPSTREAM_VERSION_pn-libopensync = "0.39"
RECIPE_UPSTREAM_DATE_pn-libowl-av = "Dec 01, 2008"
RECIPE_UPSTREAM_VERSION_pn-libowl = "0.0+svnr408"
RECIPE_UPSTREAM_DATE_pn-libowl = "Sep 01, 2008"
RECIPE_UPSTREAM_VERSION_pn-libpam = "1.1.5"
CHECK_DATE_pn-libpam = "Jan 12, 2012"
RECIPE_UPSTREAM_DATE_pn-libpam = "Oct 25, 2011"
RECIPE_UPSTREAM_VERSION_pn-libpcap="1.2.0"
RECIPE_UPSTREAM_DATE_pn-libpcap="Jul 24, 2011"
RECIPE_UPSTREAM_VERSION_pn-libpciaccess = "0.13.1"
RECIPE_UPSTREAM_DATE_pn-libpciaccess = "Apr 09, 2012"
RECIPE_UPSTREAM_VERSION_pn-libpcre = "8.31"
RECIPE_UPSTREAM_DATE_pn-libpcre = "Jul 23, 2012"
CHECK_DATE_pn-libpcre = "Jul 24, 2012"
RECIPE_NO_UPDATE_REASON_pn-libpng = "1.4.3 and later changes the API and breaks libmatchbox. Sticking with the 1.2.x series instead"
RECIPE_UPSTREAM_VERSION_pn-libpng = "1.5.11"
RECIPE_UPSTREAM_DATE_pn-libpng = "Jun 14, 2012"
CHECK_DATE_pn-libpng = "Jul 05, 2012"
RECIPE_UPSTREAM_VERSION_pn-libproxy="0.4.6"
CHECK_DATE_pn-libproxy = "Jan 30, 2011"
RECIPE_UPSTREAM_DATE_pn-libproxy="Sep 01, 2010"
RECIPE_UPSTREAM_DATE_pn-libpthread-stubs = "Oct 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-librsvg = "2.32.1"
RECIPE_UPSTREAM_DATE_pn-librsvg = "Nov 13, 2010"
RECIPE_UPSTREAM_VERSION_pn-libsamplerate0 = "0.1.8"
RECIPE_UPSTREAM_DATE_pn-libsamplerate0 = "Aug 15, 2011"
CHECK_DATE_pn-libsamplerate0 = "Jul 24, 2012"
RECIPE_UPSTREAM_VERSION_pn-libsdl = "1.2.15"
CHECK_DATE_pn-libsdl = "Mar 14, 2012"
RECIPE_UPSTREAM_VERSION_pn-libsm = "1.1.1"
RECIPE_UPSTREAM_DATE_pn-libsm = "Aug 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-libsndfile1 = "1.0.25"
RECIPE_UPSTREAM_DATE_pn-libsndfile1 = "Jul 13, 2011"
RECIPE_UPSTREAM_DATE_pn-libsoup-2.4 = "Oct 18, 2011"
RECIPE_UPSTREAM_VERSION_pn-libsoup = "2.2.105"
RECIPE_UPSTREAM_VERSION_pn-libsyncml = "0.5.4"
RECIPE_UPSTREAM_DATE_pn-libtasn1 = "Mar 19, 2012"
RECIPE_UPSTREAM_VERSION_pn-libtelepathy = "0.3.3"
RECIPE_NO_UPDATE_REASON_pn-libtheora = "1.1.1 is latest stable release not 1.2.0alpha1"
RECIPE_UPSTREAM_VERSION_pn-libtheora = "1.2.0"
RECIPE_UPSTREAM_VERSION_pn-libtimedate-perl = "1.20"
RECIPE_UPSTREAM_VERSION_pn-libtirpc = "0.2.2"
RECIPE_UPSTREAM_DATE_pn-libtirpc = "May 02, 2011"
CHECK_DATE_pn-libtirpc = "Jul 24, 2012"
RECIPE_UPSTREAM_VERSION_pn-libtool="2.4.2"
CHECK_DATE_pn-libtool = "Nov 28, 2011"
RECIPE_UPSTREAM_VERSION_pn-libunique = "2.91.4"
RECIPE_UPSTREAM_DATE_pn-libunique = "Dec 7, 2010"
RECIPE_NO_UPDATE_REASON_pn-libunique = "Do not upgrade to version: 2.91.4 because it requires gtk+ >= 2.90.0 and the stable version of gtk+ used by poky is 2.20.1"
RECIPE_UPSTREAM_VERSION_pn-libunistring = "0.9.3"
CHECK_DATE_pn-libunistring = "Jan 17, 2012"
RECIPE_UPSTREAM_VERSION_pn-liburcu = "0.6.7"
RECIPE_UPSTREAM_DATE_pn-liburcu = "Dec 12, 2011"
RECIPE_UPSTREAM_VERSION_pn-liburi-perl = "1.60"
RECIPE_UPSTREAM_DATE_pn-liburi-perl = "Mar 25, 2012"
RECIPE_UPSTREAM_DATE_pn-libusb-compat = "Jul 08, 2009"
RECIPE_UPSTREAM_VERSION_pn-libusb1 = "1.0.8"
RECIPE_UPSTREAM_DATE_pn-libusb = "May 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-libuser = "0.57.1"
RECIPE_UPSTREAM_DATE_pn-libuser = "Jan 01, 2011"
CHECK_DATE_pn-libuser = "Jan 26, 2011"
RECIPE_UPSTREAM_VERSION_pn-libvorbis="1.3.2"
RECIPE_UPSTREAM_DATE_pn-libvorbis="Nov 01, 2010"
RECIPE_UPSTREAM_DATE_pn-libx11-diet = "Nov 10, 2011"
RECIPE_UPSTREAM_VERSION_pn-libx11 = "1.4.99.1"
RECIPE_UPSTREAM_DATE_pn-libx11 = "Nov 10, 2011"
RECIPE_UPSTREAM_VERSION_pn-libxau = "1.0.5"
RECIPE_UPSTREAM_DATE_pn-libxau = "Aug 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-libxaw = "1.0.7"
RECIPE_UPSTREAM_VERSION_pn-libxcalibrate = "0.0+git0+209d83af61ed38a002c8096377deac292b3e396c"
RECIPE_UPSTREAM_DATE_pn-libxcalibrate = "Mar 01, 2008"
RECIPE_UPSTREAM_VERSION_pn-libxcb = "1.8"
RECIPE_UPSTREAM_DATE_pn-libxcb = "Jan 11, 2012"
RECIPE_UPSTREAM_VERSION_pn-libxcomposite = "0.4.1"
RECIPE_UPSTREAM_DATE_pn-libxcomposite = "Oct 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-libxcursor = "1.1.12"
RECIPE_UPSTREAM_DATE_pn-libxcursor = "Jun 30, 2011"
RECIPE_UPSTREAM_VERSION_pn-libxdamage = "1.1.2"
RECIPE_UPSTREAM_DATE_pn-libxdamage = "Oct 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-libxdmcp = "1.0.3"
RECIPE_UPSTREAM_DATE_pn-libxdmcp = "Sep 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-libxevie = "1.0.2"
RECIPE_UPSTREAM_VERSION_pn-libxext = "1.3.0"
RECIPE_UPSTREAM_DATE_pn-libxext = "May 6, 2011"
RECIPE_UPSTREAM_VERSION_pn-libxfixes = "5.0"
RECIPE_UPSTREAM_DATE_pn-libxfixes = "Mar 8, 2011"
RECIPE_UPSTREAM_VERSION_pn-libxfont = "1.4.4"
RECIPE_UPSTREAM_DATE_pn-libxfont = "Aug 10, 2011"
RECIPE_UPSTREAM_VERSION_pn-libxfontcache="1.0.5"
RECIPE_UPSTREAM_DATE_pn-libxfontcache="Oct 08, 2009"
RECIPE_UPSTREAM_VERSION_pn-libxft = "2.1.14"
RECIPE_UPSTREAM_DATE_pn-libxft = "Oct 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-libxi = "1.5.99.2"
RECIPE_UPSTREAM_DATE_pn-libxi = "Dec 21, 2011"
RECIPE_UPSTREAM_VERSION_pn-libxinerama = "1.1"
RECIPE_UPSTREAM_DATE_pn-libxinerama = "Oct 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-libxkbfile = "1.0.6"
RECIPE_UPSTREAM_DATE_pn-libxkbfile = "Oct 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-libxkbui = "1.0.2"
RECIPE_UPSTREAM_VERSION_pn-libxklavier = "5.0"
RECIPE_UPSTREAM_VERSION_pn-libxml-parser-perl="2.41"
RECIPE_UPSTREAM_DATE_pn-libxml2 = "May 21, 2012"
RECIPE_UPSTREAM_VERSION_pn-libxmu = "1.0.5"
RECIPE_UPSTREAM_DATE_pn-libxmu = "Sep 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-libxp = "1.0.1"
RECIPE_UPSTREAM_DATE_pn-libxp = "Jan 13, 2011"
RECIPE_UPSTREAM_VERSION_pn-libxpm = "3.5.9"
RECIPE_UPSTREAM_DATE_pn-libxpm = "Oct 29, 2010"
RECIPE_UPSTREAM_VERSION_pn-libxprintapputil = "1.0.1"
RECIPE_UPSTREAM_DATE_pn-libxprintapputil = "Jan 18, 2006"
RECIPE_UPSTREAM_VERSION_pn-libxprintutil = "1.0.1"
RECIPE_UPSTREAM_DATE_pn-libxprintutil = "Jan 18, 2006"
RECIPE_UPSTREAM_VERSION_pn-libxrandr = "1.3.2"
RECIPE_UPSTREAM_DATE_pn-libxrandr = "Jun 29, 2011"
RECIPE_UPSTREAM_VERSION_pn-libxrender = "0.9.5"
RECIPE_UPSTREAM_DATE_pn-libxrender = "Oct 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-libxres = "1.0.4"
RECIPE_UPSTREAM_DATE_pn-libxres = "Oct 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-libxscrnsaver = "1.2.1"
RECIPE_UPSTREAM_DATE_pn-libxscrnsaver = "Oct 29, 2010"
RECIPE_UPSTREAM_DATE_pn-libxsettings-client = "Mar 01, 2007"
RECIPE_UPSTREAM_VERSION_pn-libxslt = "1.1.26"
CHECK_DATE_pn-libxslt = "Nov 22, 2011"
RECIPE_UPSTREAM_DATE_pn-libxslt = "Sep 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-libxt = "1.1.3"
RECIPE_UPSTREAM_DATE_pn-libxt = "Mar 16, 2012"
RECIPE_UPSTREAM_VERSION_pn-libxtrap = "1.0.0"
RECIPE_UPSTREAM_DATE_pn-libxtrap = "Jan 18, 2006"
RECIPE_UPSTREAM_VERSION_pn-libxtst = "1.1.0"
RECIPE_UPSTREAM_DATE_pn-libxtst = "Oct 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-libxv = "1.0.5"
RECIPE_UPSTREAM_VERSION_pn-libxvmc = "1.0.5"
RECIPE_UPSTREAM_DATE_pn-libxvmc = "Oct 01, 2009"
RECIPE_UPSTREAM_DATE_pn-libxv = "Oct 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-libxxf86dga="1.1.1"
RECIPE_UPSTREAM_DATE_pn-libxxf86dga="Oct 06, 2009"
RECIPE_UPSTREAM_VERSION_pn-libxxf86misc = "1.0.3"
RECIPE_UPSTREAM_DATE_pn-libxxf86misc = "Nov 21, 2010"
RECIPE_UPSTREAM_VERSION_pn-libxxf86vm = "1.1.0"
RECIPE_UPSTREAM_DATE_pn-libxxf86vm = "Oct 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-libzypp = "git"
RECIPE_UPSTREAM_VERSION_pn-lighttpd = "1.4.29"
RECIPE_UPSTREAM_DATE_pn-lighttpd = "Jul 01, 2011"
RECIPE_UPSTREAM_DATE_pn-linux-firmware = "Oct 24, 2011"
RECIPE_UPSTREAM_DATE_pn-linuxdoc-tools = "unknown"
RECIPE_UPSTREAM_VERSION_pn-logrotate = "check"
RECIPE_UPSTREAM_VERSION_pn-loudmouth = "check"
RECIPE_UPSTREAM_VERSION_pn-lrzsz="0.12.20"
RECIPE_UPSTREAM_DATE_pn-lrzsz="Dec 31, 1998"
CHECK_DATE_pn-lrzsz = "Jan 30, 2011"
RECIPE_UPSTREAM_VERSION_pn-lsb = "1.4"
RECIPE_NO_UPDATE_REASON_pn-lsb = "1.4 is fixed version of LSB Test"
CHECK_DATE_pn-lsb = "Apr 18, 2012"
RECIPE_UPSTREAM_DATE_pn-lsb = "Jan 04, 2001"
RECIPE_UPSTREAM_VERSION_pn-lsbsetup = "0.9"
CHECK_DATE_pn-lsbsetup = "Nov 28, 2011"
RECIPE_UPSTREAM_VERSION_pn-lsbtest = "1.0"
RECIPE_UPSTREAM_VERSION_pn-lsof="4.84"
CHECK_DATE_pn-lsof = "Jul 06, 2011"
RECIPE_UPSTREAM_VERSION_pn-ltp = "20120614"
RECIPE_UPSTREAM_DATE_pn-ltp = "Jun 14, 2012"
CHECK_DATE_pn-ltp = "Jul 25, 2012"
RECIPE_UPSTREAM_DATE_pn-lttng-ust = "Dec 15, 2011"
RECIPE_UPSTREAM_VERSION_pn-lzo = "2.06"
RECIPE_UPSTREAM_DATE_pn-lzo = "Aug 12, 2011"
RECIPE_UPSTREAM_VERSION_pn-m4="1.4.15"
CHECK_DATE_pn-m4 = "Jul 06, 2011"
RECIPE_UPSTREAM_VERSION_pn-mailx = "12.5"
CHECK_DATE_pn-mailx = "Jul 28, 2011"
RECIPE_UPSTREAM_VERSION_pn-make="3.82"
RECIPE_UPSTREAM_VERSION_pn-makedepend = "1.0.4"
RECIPE_UPSTREAM_VERSION_pn-makedevs = "1.0.0"
RECIPE_UPSTREAM_DATE_pn-makedevs = "n/a"
CHECK_DATE_pn-make = "May 23, 2011"
RECIPE_UPSTREAM_DATE_pn-man-pages = "Dec 03, 2010"
RECIPE_UPSTREAM_VERSION_pn-man = "1.6f"
RECIPE_UPSTREAM_DATE_pn-matchbox-desktop = "Dec 01, 2008"
RECIPE_NO_UPDATE_REASON_pn-mc = ""
RECIPE_UPSTREAM_VERSION_pn-mc = "4.8.1"
RECIPE_UPSTREAM_DATE_pn-mc = "Dec 1, 2011"
RECIPE_UPSTREAM_VERSION_pn-mdadm = "3.2.5"
RECIPE_UPSTREAM_DATE_pn-mdadm = "May 18, 2012"
RECIPE_UPSTREAM_VERSION_pn-menu-cache = "0.3.3"
RECIPE_UPSTREAM_DATE_pn-menu-cache = "May 20, 2012"
CHECK_DATE_pn-minicom = "Jul 24, 2012"
RECIPE_UPSTREAM_DATE_pn-mesa-dri="Jun 17, 2010"
RECIPE_UPSTREAM_VERSION_pn-meta-ide-support = "check"
RECIPE_UPSTREAM_VERSION_pn-metacity = "2.30.3"
RECIPE_UPSTREAM_VERSION_pn-mingetty = "1.08"
CHECK_DATE_pn-mingetty = "Jul 24, 2012"
RECIPE_UPSTREAM_VERSION_pn-minicom = "2.6.1"
RECIPE_UPSTREAM_DATE_pn-minicom = "Feb 11, 2012"
CHECK_DATE_pn-minicom = "Jul 06, 2012"
RECIPE_UPSTREAM_VERSION_pn-mkfontdir="1.0.7"
RECIPE_UPSTREAM_DATE_pn-mkfontdir="Feb 10, 2012"
RECIPE_UPSTREAM_VERSION_pn-mkfontscale="1.10.0"
RECIPE_UPSTREAM_DATE_pn-mkfontscale="Feb 10, 2012"
RECIPE_UPSTREAM_VERSION_pn-mktemp="1.7"
RECIPE_UPSTREAM_VERSION_pn-mobile-broadband-provider-info = "1.0.0+git"
RECIPE_UPSTREAM_DATE_pn-module-init-tools = "Oct 01, 2009"
RECIPE_UPSTREAM_DATE_pn-modutils-initscripts = "n/a"
RECIPE_UPSTREAM_VERSION_pn-mpeg2dec = "0.5.1"
CHECK_DATE_pn-mpeg2dec = "May 24, 2011"
RECIPE_NO_UPDATE_REASON_pn-mpeg2dec = "Why are we currently at 0.4.1?"
RECIPE_UPSTREAM_VERSION_pn-mpfr="3.1.1"
RECIPE_UPSTREAM_DATE_pn-mpfr = "Jul 04, 2012"
CHECK_DATE_pn-mpfr = "Jul 06, 2012"
RECIPE_UPSTREAM_VERSION_pn-msynctool = "0.38"
RECIPE_UPSTREAM_DATE_pn-msynctool = "Nov 11, 2008"
RECIPE_UPSTREAM_DATE_pn-mtd-utils = "Dec 17, 2011"
RECIPE_UPSTREAM_VERSION_pn-mtools = "4.0.17"
RECIPE_UPSTREAM_DATE_pn-mtools = "Jun 28, 2011"
RECIPE_UPSTREAM_VERSION_pn-mutter = "2.29.1_0.4"
RECIPE_UPSTREAM_VERSION_pn-nasm="2.07"
CHECK_DATE_pn-nasm = "Feb 01, 2012"
RECIPE_UPSTREAM_VERSION_pn-ncurses = "5.9"
RECIPE_UPSTREAM_DATE_pn-ncurses = "Apr 04, 2011"
CHECK_DATE_pn-ncurses = "Nov 08, 2011"
RECIPE_UPSTREAM_VERSION_pn-neon="0.29.6"
RECIPE_UPSTREAM_DATE_pn-neon="May 03, 2011"
RECIPE_UPSTREAM_VERSION_pn-net-tools = "1.60-23"
RECIPE_UPSTREAM_VERSION_pn-netbase = "4.46"
RECIPE_UPSTREAM_DATE_pn-netbase = "Jun 06, 2011"
RECIPE_UPSTREAM_VERSION_pn-nfs-utils = "1.2.6"
CHECK_DATE_pn-nfs-utils = "Jul 05, 2012"
RECIPE_UPSTREAM_DATE_pn-nfs-utils = "May 14, 2012"
RECIPE_UPSTREAM_DATE_pn-ocf-linux = "Jan 27, 2012"
RECIPE_UPSTREAM_VERSION_pn-ofono = "1.6"
RECIPE_UPSTREAM_DATE_pn-ofono="Apr 20, 2012"
RECIPE_UPSTREAM_DATE_pn-oh-puzzles = "Oct 1, 2011"
RECIPE_UPSTREAM_VERSION_pn-openjade = "1.3.2"
RECIPE_UPSTREAM_DATE_pn-openjade = "Dec 01, 2002"
RECIPE_UPSTREAM_VERSION_pn-openobex = "1.5"
RECIPE_UPSTREAM_VERSION_pn-opensp = "1.5.2"
RECIPE_UPSTREAM_DATE_pn-opensp = "Dec 23, 2005"
CHECK_DATE_pn-opensp = "Jul 05, 2012"
RECIPE_UPSTREAM_VERSION_pn-openssh = "6.0p1"
RECIPE_UPSTREAM_DATE_pn-openssh = "Apr 22, 2012"
RECIPE_UPSTREAM_VERSION_pn-openssl = "1.0.1b"
RECIPE_NO_UPDATE_REASON_pn-openssl = "1.0.1 is beta 1.0.0i is latest"
RECIPE_UPSTREAM_DATE_pn-openssl = "Apr 26, 2012"
RECIPE_UPSTREAM_VERSION_pn-openswan = "2.6.26"
RECIPE_UPSTREAM_DATE_pn-opkg-collateral = "n/a"
RECIPE_UPSTREAM_VERSION_pn-opkg = "0.1.8"
CHECK_DATE_pn-opkg = "Jul 06, 2012"
RECIPE_UPSTREAM_DATE_pn-opkg = "Feb 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-opkg_nogpg = "0.1.8"
RECIPE_UPSTREAM_DATE_pn-opkg_nogpg = "Feb 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-oprofile = "0.9.7"
RECIPE_UPSTREAM_DATE_pn-oprofile = "Aug 12, 2011"
CHECK_DATE_pn-oprofile = "Jul 06, 2012"
RECIPE_UPSTREAM_VERSION_pn-oprofileui = "0.0+git0+82ecf8c6b53b84f80682a8312f9defa83a95f2a3"
CHECK_DATE_pn-oprofileui = "Dec 24, 2011"
RECIPE_UPSTREAM_DATE_pn-oprofileui = "Nov 14, 2011"
RECIPE_UPSTREAM_VERSION_pn-orinoco-conf = "1.0"
RECIPE_UPSTREAM_DATE_pn-owl-video = "Jun 01, 2008"
RECIPE_UPSTREAM_VERSION_pn-pango="1.28.0"
RECIPE_UPSTREAM_DATE_pn-pango="Mar 10, 2010"
RECIPE_UPSTREAM_VERSION_pn-parted = "3.0"
CHECK_DATE_pn-parted = "Nov 22, 2011"
RECIPE_LATEST_VERIONS_pn-patch = "2.6.1"
CHECK_DATE_pn-patch = "Nov 16, 2011"
RECIPE_UPSTREAM_DATE_pn-pax-utils = "Dec 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-pax = "3.4"
RECIPE_UPSTREAM_DATE_pn-pax = "Aug 01, 2005"
RECIPE_UPSTREAM_VERSION_pn-pciutils = "3.1.9"
RECIPE_UPSTREAM_DATE_pn-pciutils = "Jan 14, 2012"
RECIPE_UPSTREAM_VERSION_pn-pcmanfm = "0.9.10"
RECIPE_UPSTREAM_DATE_pn-pcmanfm = "Oct 24, 2011"
CHECK_DATE_pn-pcmanfm = "Jul 06, 2012"
RECIPE_UPSTREAM_DATE_pn-pcmanfm = "Oct 24, 2011"
RECIPE_UPSTREAM_VERSION_pn-pcmciautils = "017"
RECIPE_UPSTREAM_DATE_pn-pcmciautils = "Jan 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-perl="5.14.2"
CHECK_DATE_pn-perl = "Nov 16, 2011"
RECIPE_UPSTREAM_VERSION_pn-pixman = "0.24.4"
RECIPE_UPSTREAM_DATE_pn-pixman = "Jan 18, 2012"
RECIPE_UPSTREAM_VERSION_pn-pkgconfig = "0.26"
RECIPE_NO_UPDATE_REASON_pn-pkgconfig = "0.26 removes glib-conf, adds circular depends"
RECIPE_UPSTREAM_DATE_pn-pkgconfig = "May 15, 2011"
RECIPE_UPSTREAM_DATE_pn-pm-utils = "Jul 04, 2010"
RECIPE_UPSTREAM_VERSION_pn-pointercal = "0.0"
RECIPE_UPSTREAM_DATE_pn-pointercal = "n/a"
RECIPE_UPSTREAM_DATE_pn-poky-feed-config-opkg = "n/a"
RECIPE_UPSTREAM_DATE_pn-polkit-gnome = "Aug 16, 2011"
RECIPE_UPSTREAM_VERSION_pn-polkit = "0.104"
RECIPE_UPSTREAM_DATE_pn-polkit = "Jan 03, 2012"
RECIPE_UPSTREAM_VERSION_pn-pong-clock = "1.0"
RECIPE_UPSTREAM_VERSION_pn-poppler-data = "0.4.2"
RECIPE_UPSTREAM_VERSION_pn-poppler = "0.12.4"
RECIPE_UPSTREAM_VERSION_pn-popt = "1.16"
RECIPE_UPSTREAM_DATE_pn-popt = "May 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-portmap = "6.0"
RECIPE_UPSTREAM_DATE_pn-portmap = "May 01, 2007"
RECIPE_UPSTREAM_VERSION_pn-postinsts="1.0"
RECIPE_UPSTREAM_VERSION_pn-powertop = "1.97"
CHECK_DATE_pn-powertop = "Apr 20, 2011"
RECIPE_NO_UPDATE_REASON_pn-powertop = "Do not upgrade to version 1.97 since it's a beta release of the comming PowerTOP 2.0"
RECIPE_UPSTREAM_DATE_pn-powertop = "Jan 5, 2011"
RECIPE_UPSTREAM_VERSION_pn-ppp-dialin = "check"
RECIPE_UPSTREAM_VERSION_pn-ppp="2.4.5"
RECIPE_UPSTREAM_DATE_pn-ppp="Nov 17, 2009"
RECIPE_UPSTREAM_VERSION_pn-prelink="1.0+git1+9552f214c7faa816fdb55b289a457f0cab034f00"
CHECK_DATE_pn-prelink = "Jan 13, 2012"
RECIPE_UPSTREAM_VERSION_pn-printproto = "1.0.5"
RECIPE_UPSTREAM_DATE_pn-printproto = "Jan 5, 2011"
RECIPE_UPSTREAM_VERSION_pn-procps = "3.2.8"
RECIPE_UPSTREAM_VERSION_pn-pseudo = "1.2"
CHECK_DATE_pn-pseudo = "Nov 02, 2011"
RECIPE_UPSTREAM_VERSION_pn-psmisc = "22.19"
CHECK_DATE_pn-psmisc = "Jul 05, 2012"
RECIPE_UPSTREAM_DATE_pn-psmisc = "Jun 22, 2012"
RECIPE_UPSTREAM_VERSION_pn-psplash = "0.0+svnr424"
RECIPE_UPSTREAM_DATE_pn-psplash = "May 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-pth = "2.0.7"
RECIPE_UPSTREAM_DATE_pn-pth = "Jun 01, 2006"
RECIPE_UPSTREAM_VERSION_pn-pulseaudio = "0.9.22"
RECIPE_UPSTREAM_DATE_pn-pulseaudio = "Nov 26, 2010"
RECIPE_UPSTREAM_VERSION_pn-puzzles = "r9561"
CHECK_DATE_pn-puzzles = "Jul 06, 2012"
RECIPE_UPSTREAM_DATE_pn-python-pycurl = "Sep 01, 2008"
RECIPE_UPSTREAM_VERSION_pn-python="2.7.3"
CHECK_DATE_pn-python = "May 01, 2012"
RECIPE_UPSTREAM_DATE_pn-qemu-helper-native = "n/a"
RECIPE_UPSTREAM_VERSION_pn-qemu = "0.13.0"
RECIPE_UPSTREAM_VERSION_pn-qemugl="0.0+git0+d888bbc723c00d197d34a39b5b7448660ec1b1c0"
CHECK_DATE_pn-qemugl= "Jul 05, 2012"
RECIPE_NO_UPDATE_REASON_pn-qemugl = "Do not upgrade to version: 33466cd8 because the upstream is broken in x86_64 build"
RECIPE_UPSTREAM_DATE_pn-qemugl="May 30, 2009"
RECIPE_UPSTREAM_DATE_pn-qemu = "Oct 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-qmmp = "0.6.1"
RECIPE_UPSTREAM_DATE_pn-qmmp = "Jul 24, 2012"
RECIPE_UPSTREAM_DATE_pn-qt-mobility-embedded = "May 10, 2011"
RECIPE_UPSTREAM_DATE_pn-qt4-native = "Dec 15, 2011"
RECIPE_UPSTREAM_VERSION_pn-quicky = "0.4"
RECIPE_UPSTREAM_DATE_pn-quicky = "Jun 18, 2008"
RECIPE_UPSTREAM_VERSION_pn-quilt="0.60"
RECIPE_UPSTREAM_VERSION_pn-quota = "4.00"
RECIPE_UPSTREAM_DATE_pn-quota = "Aug 17, 2011"
CHECK_DATE_pn-quota = "Jul 24, 2012"
RECIPE_UPSTREAM_VERSION_pn-randrproto = "1.3.2"
RECIPE_UPSTREAM_DATE_pn-randrproto = "Oct 29, 2010"
RECIPE_UPSTREAM_VERSION_pn-readline = "6.2"
RECIPE_UPSTREAM_DATE_pn-readline = "Feb 13, 2011"
CHECK_DATE_pn-readline = "Nov 23, 2011"
RECIPE_UPSTREAM_VERSION_pn-recordproto = "1.14.2"
RECIPE_UPSTREAM_DATE_pn-recordproto = "Mar 23, 2012"
RECIPE_UPSTREAM_VERSION_pn-renderproto = "0.11.1"
RECIPE_UPSTREAM_DATE_pn-renderproto = "Aug 10, 2010"
RECIPE_UPSTREAM_DATE_pn-resolvconf = "Jun 19, 2012"
RECIPE_UPSTREAM_VERSION_pn-resourceproto = "1.2.0"
RECIPE_UPSTREAM_DATE_pn-resourceproto = "May 27, 2011"
RECIPE_UPSTREAM_VERSION_pn-rpcbind = "0.2.0"
RECIPE_UPSTREAM_DATE_pn-rpcbind = "May 29, 2009"
CHECK_DATE_pn-rpcbind = "Jul 24, 2012"
RECIPE_UPSTREAM_DATE_pn-rpcbind = "May 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-rpm = "5.1.10"
RECIPE_UPSTREAM_DATE_pn-rpm = "Jan 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-rsync = "3.0.7"
RECIPE_UPSTREAM_DATE_pn-rsync = "Dec 01, 2009"
RECIPE_UPSTREAM_DATE_pn-rt-tests = "Sep 26, 2011"
RECIPE_UPSTREAM_VERSION_pn-run-postinsts = "check"
RECIPE_UPSTREAM_DATE_pn-rxvt-unicode = "Jan 21, 2012"
RECIPE_UPSTREAM_VERSION_pn-sat-solver = "0.0-git1+e74e0bfd23e4e95064d08e13efb5de9caf433f40"
RECIPE_UPSTREAM_DATE_pn-sato-icon-theme = "Feb 01, 2008"
RECIPE_UPSTREAM_VERSION_pn-screen = "4.0.3"
RECIPE_UPSTREAM_DATE_pn-screen = "Aug 7, 2008"
CHECK_DATE_pn-screen = "Nov 17, 2011"
RECIPE_UPSTREAM_VERSION_pn-screenshot = "0.0+svnr292"
RECIPE_UPSTREAM_DATE_pn-screenshot = "Sep 01, 2007"
RECIPE_UPSTREAM_VERSION_pn-scrnsaverproto = "1.2.2"
RECIPE_UPSTREAM_DATE_pn-scrnsaverproto = "Mar 23, 2012"
RECIPE_UPSTREAM_VERSION_pn-sed = "4.2.1"
CHECK_DATE_pn-sed = "Jul 28, 2011"
RECIPE_UPSTREAM_DATE_pn-sed = "Jun 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-setserial = "2.17"
CHECK_DATE_pn-setserial = "Apr 25, 2012"
RECIPE_UPSTREAM_DATE_pn-setserial = "Feb 09, 2000"
RECIPE_UPSTREAM_DATE_pn-settings-daemon = "Jun 01, 2008"
RECIPE_UPSTREAM_DATE_pn-sgml-common = "May 25, 2001"
RECIPE_UPSTREAM_VERSION_pn-sgmlspl = "1.03ii"
RECIPE_UPSTREAM_DATE_pn-sgmlspl = "Dec 07, 1995"
RECIPE_UPSTREAM_VERSION_pn-shadow = "4.1.4.3"
RECIPE_UPSTREAM_DATE_pn-shadow = "Feb 15, 2011"
RECIPE_UPSTREAM_DATE_pn-shared-mime-info = "Feb 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-signgp-native = "check"
RECIPE_UPSTREAM_VERSION_pn-slang = "2.2.4"
CHECK_DATE_pn-slang = "Jun 28, 2011"
RECIPE_UPSTREAM_VERSION_pn-socat = "2.0.0"
RECIPE_NO_UPDATE_REASON_pn-socat = "2.0.0 is beta"
RECIPE_UPSTREAM_DATE_pn-socat = "Aug 07, 2011"
RECIPE_UPSTREAM_VERSION_pn-speex="1.2rc1"
RECIPE_UPSTREAM_DATE_pn-speex="Jul 24, 2008"
RECIPE_UPSTREAM_VERSION_pn-sqlite3 = "3.7.13"
RECIPE_UPSTREAM_DATE_pn-sqlite3 = "Jun 11, 2012"
CHECK_DATE_pn-sqlite3= "Jul 05, 2012"
RECIPE_UPSTREAM_VERSION_pn-squashfs-tools = "4.2"
RECIPE_UPSTREAM_DATE_pn-squashfs-tools = "Feb 28, 2011"
CHECK_DATE_pn-squashfs-tools = "Jul 06, 2012"
RECIPE_UPSTREAM_DATE_pn-startup-notification = "May 16, 2011"
RECIPE_UPSTREAM_VERSION_pn-stat = "3.3"
CHECK_DATE_pn-stat = "Dec 30, 2011"
RECIPE_UPSTREAM_VERSION_pn-strace = "4.7"
RECIPE_UPSTREAM_DATE_pn-strace = "May 02, 2012"
CHECK_DATE_pn-strace = "Jul 06, 2012"
RECIPE_UPSTREAM_VERSION_pn-subversion = "1.6.15"
CHECK_DATE_pn-subversion = "Jan 25, 2011"
RECIPE_UPSTREAM_VERSION_pn-sudo = "1.8.5p2"
RECIPE_UPSTREAM_DATE_pn-sudo = "May 29, 2012"
RECIPE_UPSTREAM_VERSION_pn-sysfsutils = "2.1.0"
CHECK_DATE_pn-sysfsutils = "Jul 05, 2012"
RECIPE_UPSTREAM_DATE_pn-sysfsutils = "Aug 23, 2006"
RECIPE_UPSTREAM_VERSION_pn-sysklogd = "1.5"
RECIPE_UPSTREAM_VERSION_pn-syslinux = "4.03"
RECIPE_UPSTREAM_DATE_pn-syslinux = "Apr 01, 2010"
RECIPE_NO_UPDATE_REASON_pn-syslinux="Waiting for 4.06 for 3.3 kernel headers support"
RECIPE_UPSTREAM_VERSION_pn-sysprof = "1.1.6"
RECIPE_UPSTREAM_VERSION_pn-sysprof = "6b5b8432711ef5c747f8375073cd9af88922d3c6"
RECIPE_UPSTREAM_DATE_pn-sysprof = "Dec 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-sysstat = "10.0.5"
CHECK_DATE_pn-sysstat = "Jul 05, 2012"
RECIPE_UPSTREAM_DATE_pn-sysstat = "May 16, 2012"
RECIPE_UPSTREAM_VERSION_pn-sysvinit = "2.88dsf"
RECIPE_UPSTREAM_DATE_pn-sysvinit = "Apr 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-table = "d42a44938699ee30a998fc42bc149aebf69389db"
RECIPE_UPSTREAM_VERSION_pn-taglib = "1.6.3"
RECIPE_UPSTREAM_DATE_pn-taglib = "Apr 19, 2010"
CHECK_DATE_pn-taglib = "Jan 30, 2011"
RECIPE_UPSTREAM_VERSION_pn-talloc = "2.0.5"
RECIPE_UPSTREAM_VERSION_pn-tar = "1.26"
RECIPE_UPSTREAM_DATE_pn-tar = "Mar 01, 2011"
CHECK_DATE_pn-tar = "Nov 14, 2011"
RECIPE_UPSTREAM_DATE_pn-task-base="n/a"
RECIPE_UPSTREAM_DATE_pn-tcf-agent = "Jul 07, 2011"
RECIPE_UPSTREAM_VERSION_pn-tcl="8.5.11"
RECIPE_UPSTREAM_DATE_pn-tcl = "Jul 07, 2011"
CHECK_DATE_pn-tcl = "Jul 06, 2012"
RECIPE_UPSTREAM_DATE_pn-tcp-wrappers = "Apr 08, 1997"
RECIPE_UPSTREAM_DATE_pn-telepathy-glib = "Apr 20, 2012"
RECIPE_UPSTREAM_VERSION_pn-texi2html = "5.0"
CHECK_DATE_pn-texi2html = "Dec 18, 2011"
RECIPE_UPSTREAM_DATE_pn-texi2html = "Jul 01, 2010"
RECIPE_UPSTREAM_VERSION_pn-texinfo = "4.13a"
RECIPE_NO_UPDATE_REASON_pn-texinfo = "Checking script parses directory wrong"
CHECK_DATE_pn-texinfo = "Nov 22, 2011"
RECIPE_UPSTREAM_DATE_pn-texinfo = "Sep 22, 2008"
RECIPE_UPSTREAM_VERSION_pn-tidy = "0.1.0+git0+e25416e1293e1074bfa6727c80527dcff5b1f3cb"
RECIPE_UPSTREAM_VERSION_pn-tiff = "4.0.1"
CHECK_DATE_pn-tiff = "Feb 27, 2012"
RECIPE_UPSTREAM_VERSION_pn-time = "1.7"
RECIPE_UPSTREAM_DATE_pn-time = "Jul 01, 1996"
RECIPE_UPSTREAM_VERSION_pn-tinylogin = "1.4"
CHECK_DATE_pn-tinylogin = "Jul 19, 2012"
RECIPE_UPSTREAM_DATE_pn-tinylogin = "Jan 03, 2003"
RECIPE_NO_UPDATE_REASON_pn-tinylogin = "TinyLogin was merged into BusyBox."
RECIPE_UPSTREAM_DATE_pn-trace-cmd = "Nov 7, 2011"
RECIPE_UPSTREAM_VERSION_pn-transfig = "3.2.5d"
RECIPE_UPSTREAM_DATE_pn-transfig = "Jul 23, 2010"
RECIPE_UPSTREAM_VERSION_pn-trapproto = "3.4.3"
RECIPE_UPSTREAM_DATE_pn-trapproto = "Jan 01, 2006"
RECIPE_UPSTREAM_VERSION_pn-tremor="20120122"
RECIPE_UPSTREAM_DATE_pn-tremor="Jan 22, 2012"
RECIPE_UPSTREAM_VERSION_pn-tslib = "1.0"
RECIPE_UPSTREAM_DATE_pn-tslib ="Sep 09, 2006"
CHECK_DATE_pn-tslib = "Jul 06, 2012"
RECIPE_UPSTREAM_DATE_pn-tslib = "Aug 01, 2006"
RECIPE_UPSTREAM_DATE_pn-ttf-bitstream-vera = "Apr 16, 2003"
RECIPE_UPSTREAM_VERSION_pn-tzdata = "2012c"
RECIPE_UPSTREAM_DATE_pn-tzdata = "Apr 02, 2012"
CHECK_DATE_pn-tzdata = "Jul 06, 2012"
RECIPE_UPSTREAM_DATE_pn-u-boot-fw-utils = "Dec 23, 2011"
RECIPE_UPSTREAM_VERSION_pn-ubootchart = "0.0+r12"
RECIPE_UPSTREAM_DATE_pn-udev-extraconf = "n/a"
RECIPE_UPSTREAM_VERSION_pn-udev = "164"
RECIPE_UPSTREAM_DATE_pn-udev = "Jan 11, 2012"
RECIPE_UPSTREAM_VERSION_pn-unifdef="2.6.18+git"
RECIPE_UPSTREAM_VERSION_pn-unzip = "6.0"
RECIPE_UPSTREAM_DATE_pn-unzip = "Apr 25, 2009"
CHECK_DATE_pn-unzip = "Jul 06, 2012"
RECIPE_UPSTREAM_DATE_pn-update-rc.d = "unknown"
RECIPE_UPSTREAM_VERSION_pn-usbinit = "n/a"
RECIPE_UPSTREAM_VERSION_pn-usbutils = "0.91"
RECIPE_UPSTREAM_DATE_pn-usbutils = "Oct 22, 2010"
CHECK_DATE_pn-usbutils = "Apr 18, 2012"
RECIPE_UPSTREAM_DATE_pn-util-linux = "Feb 24, 2012"
RECIPE_UPSTREAM_VERSION_pn-v86d = "0.1.10"
RECIPE_UPSTREAM_DATE_pn-v86d = "Feb 25, 2011"
RECIPE_UPSTREAM_VERSION_pn-valgrind = "3.7.0"
RECIPE_UPSTREAM_DATE_pn-valgrind = "Nov 05, 2011"
RECIPE_UPSTREAM_VERSION_pn-videoproto = "2.3.1"
RECIPE_UPSTREAM_DATE_pn-videoproto = "Aug 10, 2010"
RECIPE_UPSTREAM_VERSION_pn-vte="0.24.3"
RECIPE_UPSTREAM_DATE_pn-vte="Jul 12, 2010"
RECIPE_UPSTREAM_VERSION_pn-watchdog = "5.12"
RECIPE_UPSTREAM_DATE_pn-watchdog = "Apr 05, 2012"
CHECK_DATE_pn-watchdog = "Jul 06, 2012"
RECIPE_UPSTREAM_VERSION_pn-wbxml2 = "0.10.8"
RECIPE_UPSTREAM_DATE_pn-web-webkit = "Aug 01, 2008"
RECIPE_UPSTREAM_VERSION_pn-web = "0.0+svnr129"
RECIPE_UPSTREAM_VERSION_pn-webkit-gtk = "1.8.1"
RECIPE_UPSTREAM_DATE_pn-webkit-gtk = "Apr 24, 2012"
CHECK_DATE_pn-webkit-gtk = "Jul 06, 2012"
RECIPE_UPSTREAM_VERSION_pn-which = "2.20"
RECIPE_UPSTREAM_DATE_pn-which = "Aug 01, 2008"
CHECK_DATE_pn-which = "Nov 22, 2011"
RECIPE_UPSTREAM_VERSION_pn-wireless-tools = "29"
RECIPE_UPSTREAM_DATE_pn-wireless-tools="Sep 18, 2007"
CHECK_DATE_pn-wireless-tools = "Jul 24, 2012"
RECIPE_UPSTREAM_DATE_pn-wpa-supplicant="Sep 07, 2010"
RECIPE_UPSTREAM_VERSION_pn-wv = "1.2.1"
RECIPE_UPSTREAM_DATE_pn-x11-common="Sep 22, 2008"
RECIPE_UPSTREAM_VERSION_pn-x11perf = "1.5.4"
RECIPE_UPSTREAM_VERSION_pn-x11vnc = "0.9.13"
RECIPE_UPSTREAM_DATE_pn-x11vnc = "Sep 13, 2011"
CHECK_DATE_pn-x11vnc = "Jul 06, 2012"
RECIPE_UPSTREAM_VERSION_pn-xauth="1.0.5"
RECIPE_UPSTREAM_DATE_pn-xauth="Sep 24, 2010"
RECIPE_UPSTREAM_VERSION_pn-xbacklight = "1.1.1"
RECIPE_UPSTREAM_DATE_pn-xcb-proto = "Mar 23, 2012"
RECIPE_UPSTREAM_VERSION_pn-xcmiscproto = "1.2.2"
RECIPE_UPSTREAM_DATE_pn-xcmiscproto = "Mar 23, 2012"
RECIPE_UPSTREAM_DATE_pn-xcursor-transparent-theme = "Dec 01, 2004"
RECIPE_UPSTREAM_VERSION_pn-xdg-utils = "1.0.2"
RECIPE_UPSTREAM_VERSION_pn-xdpyinfo="1.3.0"
RECIPE_UPSTREAM_DATE_pn-xdpyinfo="Oct 21, 2011"
RECIPE_UPSTREAM_VERSION_pn-xev = "1.0.4"
RECIPE_UPSTREAM_VERSION_pn-xextproto = "7.2.1"
RECIPE_UPSTREAM_DATE_pn-xextproto = "Mar 23, 2012"
RECIPE_UPSTREAM_VERSION_pn-xeyes = "1.1.0"
RECIPE_UPSTREAM_DATE_pn-xf86-input-keyboard="Jan 03, 2012"
RECIPE_UPSTREAM_VERSION_pn-xf86bigfontproto = "1.2.0"
RECIPE_UPSTREAM_DATE_pn-xf86bigfontproto = "Aug 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-xf86dgaproto = "2.1"
RECIPE_UPSTREAM_DATE_pn-xf86dgaproto = "Oct 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-xf86driproto = "2.1.1"
RECIPE_UPSTREAM_DATE_pn-xf86driproto = "Jan 5, 2011"
RECIPE_UPSTREAM_VERSION_pn-xf86miscproto = "0.9.3"
RECIPE_UPSTREAM_DATE_pn-xf86miscproto = "Oct 01, 2009"
RECIPE_UPSTREAM_VERSION_pn-xf86rushproto = "1.1.2"
RECIPE_UPSTREAM_DATE_pn-xf86rushproto = "Jan 01, 2006"
RECIPE_UPSTREAM_VERSION_pn-xf86vidmodeproto = "2.3.1"
RECIPE_UPSTREAM_DATE_pn-xf86vidmodeproto = "Jan 5, 2011"
RECIPE_UPSTREAM_VERSION_pn-xhost="1.0.3"
RECIPE_UPSTREAM_DATE_pn-xhost="Oct 14, 2009"
RECIPE_UPSTREAM_VERSION_pn-xineramaproto = "1.2.1"
RECIPE_UPSTREAM_DATE_pn-xineramaproto = "Jan 5, 2011"
RECIPE_UPSTREAM_VERSION_pn-xinetd="2.3.14"
RECIPE_UPSTREAM_VERSION_pn-xinit="1.3.2"
RECIPE_UPSTREAM_DATE_pn-xinit="Jan 27, 2012"
RECIPE_UPSTREAM_VERSION_pn-xinput = "1.14"
RECIPE_UPSTREAM_DATE_pn-xinput = "Aug 07, 2011"
RECIPE_UPSTREAM_VERSION_pn-xkbcomp="1.2.3"
RECIPE_UPSTREAM_DATE_pn-xkbcomp="Jun 21, 2011"
RECIPE_UPSTREAM_DATE_pn-xkeyboard-config = "Sep 15, 2011"
RECIPE_UPSTREAM_VERSION_pn-xmodmap="1.0.5"
RECIPE_UPSTREAM_DATE_pn-xmodmap="Sep 24, 2010"
RECIPE_UPSTREAM_DATE_pn-xorg-minimal-fonts = "n/a"
RECIPE_UPSTREAM_VERSION_pn-xournal = "0.4.5"
RECIPE_UPSTREAM_VERSION_pn-xprop="1.2.1"
RECIPE_UPSTREAM_DATE_pn-xprop="Jun 29, 2011"
RECIPE_UPSTREAM_VERSION_pn-xproto = "7.0.23"
RECIPE_UPSTREAM_DATE_pn-xproto = "Mar 16, 2012"
RECIPE_UPSTREAM_VERSION_pn-xproxymanagementprotocol = "1.0.3"
RECIPE_UPSTREAM_DATE_pn-xproxymanagementprotocol = "Oct 12, 2009"
RECIPE_UPSTREAM_VERSION_pn-xrandr="1.3.5"
RECIPE_UPSTREAM_DATE_pn-xrandr="Jun 29, 2011"
RECIPE_UPSTREAM_VERSION_pn-xrdb = "1.0.6"
RECIPE_UPSTREAM_VERSION_pn-xrestop = "0.4"
RECIPE_UPSTREAM_DATE_pn-xrestop = "Mar 01, 2006"
CHECK_DATE_pn-xrestop = "Nov 18, 2010"
RECIPE_UPSTREAM_DATE_pn-xserver-nodm-init=""
RECIPE_UPSTREAM_VERSION_pn-xset="1.2.2"
RECIPE_UPSTREAM_DATE_pn-xset="Jul 28, 2011"
RECIPE_UPSTREAM_VERSION_pn-xtrans = "1.2.7"
RECIPE_UPSTREAM_DATE_pn-xtrans = "Mar 23, 2012"
RECIPE_UPSTREAM_VERSION_pn-xtscal = "0.6.3"
RECIPE_UPSTREAM_DATE_pn-xtscal = "Jun 01, 2006"
RECIPE_UPSTREAM_DATE_pn-xvideo-tests="Jun 22, 2007"
RECIPE_UPSTREAM_VERSION_pn-xvinfo = "1.1.1"
RECIPE_UPSTREAM_VERSION_pn-xwininfo="1.1.2"
RECIPE_UPSTREAM_DATE_pn-xwininfo="Jun 29, 2010"
RECIPE_UPSTREAM_VERSION_pn-xz = "5.0.3"
RECIPE_UPSTREAM_DATE_pn-xz = "May 21, 2011"
RECIPE_UPSTREAM_VERSION_pn-yaffs2-utils = "HEAD"
RECIPE_UPSTREAM_VERSION_pn-zaurusd = "0.0+svnr426"
CHECK_DATE_pn-zaurusd = "Jul 12, 2011"
RECIPE_NO_UPDATE_REASON_pn-zaurusd = "SVN rev 426 is last Stable release"
RECIPE_UPSTREAM_VERSION_pn-zeroconf = "0.9"
RECIPE_UPSTREAM_VERSION_pn-zip = "3.0"
RECIPE_UPSTREAM_DATE_pn-zip = "Sep 01, 2009"
CHECK_DATE_pn-zip = "Jul 06, 2012"
RECIPE_UPSTREAM_VERSION_pn-zlib = "1.2.5"
RECIPE_UPSTREAM_DATE_pn-zlib = "Mar 01, 2010"
RECIPE_NO_UPDATE_REASON_pn-zlib = "zlib-1.2.5 is latest, version parser reports 121 in error"
RECIPE_UPSTREAM_VERSION_pn-zypper = "git"
